caellion-python-commons: parse-tests.py File Reference

caellion-python-commons

Namespaces | Variables
parse-tests.py File Reference

Go to the source code of this file.

## Namespaces
| parse-tests
| parse
| -tests This script parses test results, adding Linux or Windows prefix to test names.

## Variables
| parse-tests.tree = ET.parse("reports/nose2-junit.xml")
| parse-tests.root = tree.getroot()
| parse-tests.classname = subelement.get("classname")
| parse-tests.encoding
| parse-tests.xml_declaration